pub enum GattRequest {
ResolvePeerAttHandle {
payload: GattResolvePeerAttHandleRequest,
responder: GattResolvePeerAttHandleResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: GattControlHandle,
method_type: MethodType,
},
}Variants
ResolvePeerAttHandle
Resolves a peer’s attribute handle into a service and characteristic handle.
- error Returns
MISSING_PARAMETERSifidorattribute_handleis missing. - error Returns
HANDLE_NOT_FOUNDifattribute_handleis not found. - error Returns
INTERNALif an underlying GATT procedure fails.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: GattControlHandle
method_type: MethodTypeImplementations
Sourceimpl GattRequest
impl GattRequest
pub fn into_resolve_peer_att_handle( self, ) -> Option<(GattResolvePeerAttHandleRequest, GattResolvePeerAttHandleResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL