pub struct GattMarker;Trait Implementations
Sourceimpl Clone for GattMarker
impl Clone for GattMarker
Sourcefn clone(&self) -> GattMarker
fn clone(&self) -> GattMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GattMarker
impl Debug for GattMarker
Sourceimpl DiscoverableProtocolMarker for GattMarker
impl DiscoverableProtocolMarker for GattMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for GattMarker
impl Hash for GattMarker
Sourceimpl Ord for GattMarker
impl Ord for GattMarker
Sourcefn cmp(&self, other: &GattMarker) -> Ordering
fn cmp(&self, other: &GattMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GattMarker
impl PartialEq for GattMarker
Sourcefn eq(&self, other: &GattMarker) -> bool
fn eq(&self, other: &GattMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for GattMarker
impl PartialOrd for GattMarker
Sourceimpl ProtocolMarker for GattMarker
impl ProtocolMarker for GattMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.bluetooth.test.Gatt"
const DEBUG_NAME: &'static str = "fuchsia.bluetooth.test.Gatt"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = GattProxy
type Proxy = GattProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = GattRequestStream
type RequestStream = GattRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = GattSynchronousProxy
type SynchronousProxy = GattSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for GattMarker
impl Eq for GattMarker
impl StructuralPartialEq for GattMarker