pub struct GattProxy { /* private fields */ }Implementations
Sourceimpl GattProxy
impl GattProxy
Sourcepub fn take_event_stream(&self) -> GattEventStream
pub fn take_event_stream(&self) -> GattEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn resolve_peer_att_handle(
&self,
payload: &GattResolvePeerAttHandleRequest,
) -> QueryResponseFut<GattResolvePeerAttHandleResult, DefaultFuchsiaResourceDialect>
pub fn resolve_peer_att_handle( &self, payload: &GattResolvePeerAttHandleRequest, ) -> QueryResponseFut<GattResolvePeerAttHandleResult, DefaultFuchsiaResourceDialect>
Resolves a peer’s attribute handle into a service and characteristic handle.
- error Returns
MISSING_PARAMETERSifidorattribute_handleis missing. - error Returns
HANDLE_NOT_FOUNDifattribute_handleis not found. - error Returns
INTERNALif an underlying GATT procedure fails.