pub struct GattSynchronousProxy { /* private fields */ }Implementations
Sourceimpl GattSynchronousProxy
impl GattSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<GattEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<GattEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn resolve_peer_att_handle(
&self,
payload: &GattResolvePeerAttHandleRequest,
___deadline: MonotonicInstant,
) -> Result<GattResolvePeerAttHandleResult, Error>
pub fn resolve_peer_att_handle( &self, payload: &GattResolvePeerAttHandleRequest, ___deadline: MonotonicInstant, ) -> Result<GattResolvePeerAttHandleResult, Error>
Resolves a peer’s attribute handle into a service and characteristic handle.
- error Returns
MISSING_PARAMETERSifidorattribute_handleis missing. - error Returns
HANDLE_NOT_FOUNDifattribute_handleis not found. - error Returns
INTERNALif an underlying GATT procedure fails.